Queue

Struct Queue 

pub struct Queue<'a, T: 'a, A: Allocator> { /* private fields */ }
A first-in, first-out data structure backed by a Deque

Implementations

Source

impl<'a, T: 'a, A: Allocator> Queue<'a, T, A>

pub fn into_inner(self) -> Deque<'a, T, A>

Turns the Queue into its inner Deque

pub fn is_empty(&self) -> bool

Returns true if the queue contains no elements

pub fn iter(&self) -> Iter<'a, T>

Produces an iterator over all of the elements in the queue

pub fn iter_mut(&mut self) -> IterMut<'a, T>

Produces a mutable iterator over all of the elements in the queue

pub fn len(&self) -> usize

Returns the number of elements in the queue

pub unsafe fn new_in(allocator: A) -> Self

Creates a new queue inside an allocator

Arguments

allocator: The allocator

Safety

The allocator specified must safely allocate ande de-allocate valid memory

pub fn pop(&mut self) -> Option<T>

Pops an element from the queue, returning the element on top if there was one

pub fn push(&mut self, elem: T)

Pushes an element to the queue

pub fn top(&self) -> Option<&T>

Peeks the top element in the queue without popping it